==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AInvokeExpression.h <==
// public final class soot.jimple.parser.node.AInvokeExpression

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce0769ede52622de soot_jimple_parser_node_AInvokeExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AInvokeExpression_H_
#define _JC_soot_jimple_parser_node_AInvokeExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PInvokeExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs	_jc_soot_jimple_parser_node_AInvokeExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$refs	_jc_soot_jimple_parser_node_AInvokeExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$nonrefs	_jc_soot_jimple_parser_node_AInvokeExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$object	_jc_soot_jimple_parser_node_AInvokeExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vmethods	_jc_soot_jimple_parser_node_AInvokeExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vtable	_jc_soot_jimple_parser_node_AInvokeExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vtype	_jc_soot_jimple_parser_node_AInvokeExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$_init$642b7cfa4107f038(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
extern struct _jc_soot_jimple_parser_node_PInvokeExpr$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$getInvokeExpr$ecbde525f2a90c98(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$setInvokeExpr$06105a78fa273c82(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$getInvokeExpr$ecbde525f2a90c98;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$setInvokeExpr$06105a78fa273c82;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInvokeExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
	struct _jc_soot_jimple_parser_node_PInvokeExpr$object	*(*getInvokeExpr$ecbde525f2a90c98)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setInvokeExpr$06105a78fa273c82)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AInvokeExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AInvokeExpression$vmethods	soot_jimple_parser_node_AInvokeExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInvokeExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInvokeExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PInvokeExpr$object	*__5finvokeExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInvokeExpression$refs {
    _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs	soot_jimple_parser_node_AInvokeExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInvokeExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs	soot_jimple_parser_node_AInvokeExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInvokeExpression$object {
	_jc_soot_jimple_parser_node_AInvokeExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInvokeExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInvokeExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInvokeExpression$vtype _jc_soot_jimple_parser_node_AInvokeExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInvokeExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInvokeExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInvokeExpression_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AInvokeExpression.h <==
// public final class soot.jimple.parser.node.AInvokeExpression

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce0769ede52622de soot_jimple_parser_node_AInvokeExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AInvokeExpression_H_
#define _JC_soot_jimple_parser_node_AInvokeExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PInvokeExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs	_jc_soot_jimple_parser_node_AInvokeExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$refs	_jc_soot_jimple_parser_node_AInvokeExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$nonrefs	_jc_soot_jimple_parser_node_AInvokeExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInvokeExpression$object	_jc_soot_jimple_parser_node_AInvokeExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vmethods	_jc_soot_jimple_parser_node_AInvokeExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vtable	_jc_soot_jimple_parser_node_AInvokeExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInvokeExpression$vtype	_jc_soot_jimple_parser_node_AInvokeExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$_init$642b7cfa4107f038(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PInvokeExpr$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$getInvokeExpr$ecbde525f2a90c98(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInvokeExpression$method$setInvokeExpr$06105a78fa273c82(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInvokeExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$getInvokeExpr$ecbde525f2a90c98;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$setInvokeExpr$06105a78fa273c82;
extern _jc_method _jc_soot_jimple_parser_node_AInvokeExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInvokeExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PInvokeExpr$object	*(*getInvokeExpr$ecbde525f2a90c98)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setInvokeExpr$06105a78fa273c82)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *, struct _jc_soot_jimple_parser_node_PInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInvokeExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AInvokeExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AInvokeExpression$vmethods	soot_jimple_parser_node_AInvokeExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInvokeExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInvokeExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PInvokeExpr$object	*__5finvokeExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInvokeExpression$refs {
    _jc_soot_jimple_parser_node_AInvokeExpression$sub_refs	soot_jimple_parser_node_AInvokeExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInvokeExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AInvokeExpression$sub_nonrefs	soot_jimple_parser_node_AInvokeExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInvokeExpression$object {
	_jc_soot_jimple_parser_node_AInvokeExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInvokeExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInvokeExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInvokeExpression$vtype _jc_soot_jimple_parser_node_AInvokeExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInvokeExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInvokeExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInvokeExpression_H_ */
